from copy import Error
from enum import Enum
from re import S
from ssl import OP_ALL
from typing import Dict, List, Optional, Text, Union
from typing_extensions import Literal

from pydantic import BaseModel, root_validator

from nonebot.typing import overrides
from nonebot.adapters import Event as BaseEvent
from typing import Any

from .message import Message, MessageSegment
from .models import *


class Event(BaseEvent):
    """
    telegram协议事件。
    """

    @overrides(BaseEvent)
    def get_type(self) -> Literal["message", "notice", "request", "meta_event"]:
        raise ValueError("Event has no type!")

    @overrides(BaseEvent)
    def get_event_name(self) -> str:
        raise ValueError("Event has no name!")

    @overrides(BaseEvent)
    def get_event_description(self) -> str:
        raise ValueError("Event has no description!")

    @overrides(BaseEvent)
    def get_message(self) -> "Message":
        raise ValueError("Event has no message!")

    @overrides(BaseEvent)
    def get_plaintext(self) -> str:
        raise ValueError("Event has no plaintext!")

    @overrides(BaseEvent)
    def get_user_id(self) -> str:
        raise ValueError("Event has no user_id!")

    @overrides(BaseEvent)
    def get_session_id(self) -> str:
        raise ValueError("Event has no session_id!")

    @overrides(BaseEvent)
    def is_tome(self) -> bool:
        return True


class MessageEvent(Event):
    """消息事件"""
    update_id: int
    message: Optional[MessageBody]
    edited_message: Optional[MessageBody]
    channel_post: Optional[MessageBody]
    edited_channel_post: Optional[MessageBody]
    inline_query: Optional[InlineQuery]
    chosen_inline_result: Optional[ChosenInlineResult]
    callback_query: Optional[CallbackQuery]

    message_struct: Optional[Message]

    user_id: Optional[int]
    group_id: Optional[int]

    to_me: bool = True

    @overrides(Event)
    def get_type(self) -> Literal["message", "notice", "request", "meta_event"]:
        return "message"

    @overrides(Event)
    def get_event_name(self) -> str:
        return f"{self.get_type()}.{self.message.chat.type.name}"

    @overrides(Event)
    def get_event_description(self) -> str:
        return f'Message[{self.message.chat.type}] {self.message.message_id} from {self.message.from_.id} in {self.message.chat.id} "{self.get_plaintext()}"'

    def get_message_struct(self) -> Message:
        if self.message.text:
            return Message(self.message.text)
        data = {}
        if self.message.caption:
            data["caption"] = self.message.caption
        if self.message.photo:
            data.update(self.message.photo[0].dict())
            data["photo"] = self.message.photo[0].file_id
            return Message([{"type": "photo", "data": data}])
        elif self.message.document:
            data.update(self.message.document.dict())
            data["document"] = self.message.document.file_id
            return Message([{"type": "document", "data": data}])
        elif self.message.sticker:
            data.update(self.message.sticker.dict())
            data["sticker"] = self.message.sticker.file_id
            return Message([{"type": "sticker", "data": data}])
        elif self.message.voice:
            data.update(self.message.voice.dict())
            data["voice"] = self.message.voice.file_id
            return Message([{"type": "voice", "data": data}])
        elif self.message.audio:
            data.update(self.message.audio.dict())
            data["audio"] = self.message.audio.file_id
            return Message([{"type": "audio", "data": data}])
        elif self.message.animation:
            data.update(self.message.animation.dict())
            data["animation"] = self.message.animation.file_id
            return Message([{"type": "animation", "data": data}])
        elif self.message.video:
            data.update(self.message.video.dict())
            data["video"] = self.message.video.file_id
            return Message([{"type": "video", "data": data}])
        elif self.message.video_note:
            data.update(self.message.video_note.dict())
            data["video_note"] = self.message.video_note.file_id
            return Message([{"type": "video_note", "data": data}])
        return Message("")

    @overrides(Event)
    def get_message(self) -> Message:
        if not self.message_struct:
            msg_struct: Message = self.get_message_struct()
            self.message_struct = msg_struct
        return self.message_struct

    @overrides(Event)
    def get_plaintext(self) -> str:
        return self.get_message().extract_plain_text()

    @overrides(Event)
    def get_user_id(self) -> str:
        return self.message.from_.id

    @overrides(Event)
    def get_session_id(self) -> str:
        return f"{self.message.chat.id}_{self.message.from_.id}"

    @overrides(Event)
    def is_tome(self) -> bool:
        return self.to_me


class PrivateMessageEvent(MessageEvent):
    """私聊消息"""
    pass


class GroupMessageEvent(MessageEvent):
    """群聊消息"""
    to_me = False
    # @overrides(MessageEvent)
    # def is_tome(self) -> bool:
    #    return self.isInAtList

    @overrides(Event)
    def get_session_id(self) -> str:
        return f"group_{self.message.chat.id}_{self.message.from_.id}"


class CallbackQueryEvent(MessageEvent):
    """CallbackQuery消息"""
    @overrides(Event)
    def get_type(self) -> Literal["message", "notice", "request", "meta_event"]:
        return "message"

    @overrides(Event)
    def get_event_name(self) -> str:
        return f"{self.get_type()}.callback_query"

    @overrides(Event)
    def get_event_description(self) -> str:
        return f'Message[{self.get_event_name()}] {self.callback_query.id} from {self.callback_query.from_.id} "{self.callback_query.data}"'

    @overrides(Event)
    def get_plaintext(self) -> str:
        return self.callback_query.data

    @overrides(Event)
    def get_session_id(self) -> str:
        return f"{self.callback_query.message.chat.id}_{self.callback_query.from_.id}"

    @overrides(Event)
    def get_message(self) -> Message:
        return Message([{"type": "text", "data": {"type": "callback_query", "text": self.callback_query.data}}])


class NewChatMembersEvent(MessageEvent):
    """入群事件"""
    @overrides(Event)
    def get_type(self) -> Literal["message", "notice", "request", "meta_event"]:
        return "notice"

    @overrides(Event)
    def get_event_name(self) -> str:
        return f"{self.get_type()}.new_chat_members"

    @overrides(Event)
    def get_event_description(self) -> str:
        return f'Message[{self.get_event_name()}] {len(self.message.new_chat_members)} new member(s) to {self.message.chat.title}'

    @overrides(Event)
    def get_session_id(self) -> str:
        return f"{self.message.chat.id}"

    def get_members_info(self) -> List[MessageUser]:
        return self.message.new_chat_members


class LeafChatMemberEvent(MessageEvent):
    """退群事件"""
    @overrides(Event)
    def get_type(self) -> Literal["message", "notice", "request", "meta_event"]:
        return "notice"

    @overrides(Event)
    def get_event_name(self) -> str:
        return f"{self.get_type()}.left_chat_member"

    @overrides(Event)
    def get_event_description(self) -> str:
        if self.message.left_chat_member.username:
            return f'Message[{self.get_event_name()}] {self.message.left_chat_member.username} leaf chat {self.message.chat.title}'
        else:
            return f'Message[{self.get_event_name()}] {self.message.left_chat_member.id} leaf chat {self.message.chat.title}'

    @overrides(Event)
    def get_session_id(self) -> str:
        return f"{self.message.chat.id}"

    def get_member_info(self) -> List[MessageUser]:
        return self.message.left_chat_member

class NewChatTitleEvent(MessageEvent):
    """群名（聊天标题）变更事件"""
    @overrides(Event)
    def get_type(self) -> Literal["message", "notice", "request", "meta_event"]:
        return "notice"

    @overrides(Event)
    def get_event_name(self) -> str:
        return f"{self.get_type()}.new_chat_title"

    @overrides(Event)
    def get_event_description(self) -> str:
        return f'Message[{self.get_event_name()}] chat {self.message.chat.id} change title to {self.message.chat.title}'

    @overrides(Event)
    def get_session_id(self) -> str:
        return f"{self.message.chat.id}"

    def get_chat_name(self) -> str:
        return self.message.new_chat_title

class NewChatPhotoEvent(MessageEvent):
    """群头像（聊天头像）变更事件"""
    @overrides(Event)
    def get_type(self) -> Literal["message", "notice", "request", "meta_event"]:
        return "notice"

    @overrides(Event)
    def get_event_name(self) -> str:
        return f"{self.get_type()}.new_chat_photo"

    @overrides(Event)
    def get_event_description(self) -> str:
        return f'Message[{self.get_event_name()}] chat {self.message.chat.id} change chat photo to {self.message.new_chat_photo[0].file_id}'

    @overrides(Event)
    def get_session_id(self) -> str:
        return f"{self.message.chat.id}"

    def get_chat_photo(self) -> PhotoSizeItem:
        return self.message.new_chat_photo[0]

class DeleteChatPhotoEvent(MessageEvent):
    """群头像（聊天头像）删除事件"""
    @overrides(Event)
    def get_type(self) -> Literal["message", "notice", "request", "meta_event"]:
        return "notice"

    @overrides(Event)
    def get_event_name(self) -> str:
        return f"{self.get_type()}.delete_chat_photo"

    @overrides(Event)
    def get_event_description(self) -> str:
        return f'Message[{self.get_event_name()}] chat {self.message.chat.id} delete chat photo'

    @overrides(Event)
    def get_session_id(self) -> str:
        return f"{self.message.chat.id}"

class VoiceChatStartedEvent(MessageEvent):
    """语言聊天开始事件"""
    @overrides(Event)
    def get_type(self) -> Literal["message", "notice", "request", "meta_event"]:
        return "notice"

    @overrides(Event)
    def get_event_name(self) -> str:
        return f"{self.get_type()}.voice_chat_started"

    @overrides(Event)
    def get_event_description(self) -> str:
        return f'Message[{self.get_event_name()}] chat {self.message.chat.id} start voice chat'

    @overrides(Event)
    def get_session_id(self) -> str:
        return f"{self.message.chat.id}"

    def get_voice_chat_started(self) -> VoiceChatStarted:
        return self.message.voice_chat_started

class VoiceChatEndedEvent(MessageEvent):
    """语言聊天结束事件"""
    @overrides(Event)
    def get_type(self) -> Literal["message", "notice", "request", "meta_event"]:
        return "notice"

    @overrides(Event)
    def get_event_name(self) -> str:
        return f"{self.get_type()}.voice_chat_ended"

    @overrides(Event)
    def get_event_description(self) -> str:
        return f'Message[{self.get_event_name()}] chat {self.message.chat.id} start voice chat'

    @overrides(Event)
    def get_session_id(self) -> str:
        return f"{self.message.chat.id}"

    def get_voice_chat_ended(self) -> VoiceChatEnded:
        return self.message.voice_chat_ended




from nonebot import adapters
from typing import Optional

from pydantic import Field, BaseModel


class Config(BaseModel):
    """
    telegram配置类

    :配置项:

      - ``webhook_host`` / ``telegram_webhook_host``: webhook的host
      - ``bot_token`` / ``telegram_bot_token``: bot_token
      - ``telegram_command_only`` / ``telegram_command_only``: 不处理非command的消息
    """
    webhook_host: Optional[str] = Field(default=None, alias="telegram_webhook_host")
    bot_token: Optional[str] = Field(default=None, alias="telegram_bot_token")
    telegram_adapter_debug: Optional[bool] = Field(default=False, alias="telegram_adapter_debug")
    telegram_command_only: Optional[bool] = Field(default=False, alias="telegram_command_only")

    class Config:
        extra = "ignore"
        allow_population_by_field_name = True



"""
telegram 协议适配
============================

"""

from .utils import log
from .bot import Bot
from .message import Message, MessageSegment
from .event import Event, MessageEvent, PrivateMessageEvent, GroupMessageEvent, CallbackQueryEvent
from .exception import (TelegramAdapterException, ApiNotAvailable, NetworkError,
                        ActionFailed)



from typing import Dict, List, Optional, Text, Union
from typing_extensions import Literal

from pydantic import BaseModel, root_validator
from enum import Enum


class MessageType(str, Enum):
    private = "private"
    group = "group"
    supergroup = "supergroup"
    channel = "channel"

class MessageEntityType(str, Enum):
    mention = "mention"
    hashtag = "hashtag"
    cashtag = "cashtag"
    bot_command = "bot_command"
    url = "url"
    email = "email"
    phone_number = "phone_number"
    bold = "bold"
    italic = "italic"
    underline = "underline"
    strikethrough = "strikethrough"
    code = "code"
    pre = "pre"
    text_link = "text_link"
    text_mention = "text_mention"

class MessageUser(BaseModel):
    id: int
    is_bot: bool
    first_name: str
    last_name: Optional[str]
    username: Optional[str]
    language_code: Optional[str]


class ChatPermissions(BaseModel):
    can_send_messages: Optional[bool]
    can_send_media_messages: Optional[bool]
    can_send_polls: Optional[bool]
    can_send_other_messages: Optional[bool]
    can_add_web_page_previews: Optional[bool]
    can_change_info: Optional[bool]
    can_invite_users: Optional[bool]
    can_pin_messages: Optional[bool]


class MaskPosition(BaseModel):
    point: str
    x_shift: float
    y_shift: float
    scale: float


class ChatPhoto(BaseModel):
    small_file_id: str
    small_file_unique_id: str
    big_file_id: str
    big_file_unique_id: str


class ChosenInlineResult(BaseModel):
    @root_validator(pre=True)
    def gen_message(cls, values: dict):
        if "from" in values:
            values["from_"] = values["from"]
            del values["from"]
        return values
    result_id: str
    from_: MessageUser
    location: Optional[dict]
    inline_message_id: Optional[str]
    query: str


class LocationMessage(BaseModel):
    longitude: float
    latitude: float
    horizontal_accuracy: Optional[float]
    live_period: Optional[int]
    heading: Optional[int]
    proximity_alert_radius: Optional[int]

class MessageChat(BaseModel):
    id: int
    type: MessageType
    title: Optional[str]
    username: Optional[str]
    first_name: Optional[str]
    last_name: Optional[str]
    # not in document
    all_members_are_administrators: Optional[bool]
    # Returned only in getChat
    photo: Optional[ChatPhoto]
    bio: Optional[str]
    description: Optional[str]
    invite_link: Optional[str]
    pinned_message: Optional[Dict]  # type: MessageBody
    permissions: Optional[ChatPermissions]
    slow_mode_delay: Optional[int]
    message_auto_delete_time: Optional[int]
    sticker_set_name: Optional[str]
    can_set_sticker_set: Optional[bool]
    linked_chat_id: Optional[int]
    location: Optional[LocationMessage]


class ChatInviteLink(BaseModel):
    invite_link: str
    creator: MessageUser
    is_primary: bool
    is_revoked: bool
    expire_date: Optional[int]
    member_limit: Optional[int]

class ChatMember(BaseModel):
    status: str
    user: MessageUser


class ChatMemberOwner(ChatMember):
    status: str = "creator"
    is_anonymous: bool
    custom_title: str


class ChatMemberAdministrator(ChatMember):
    status: str = "administrator"
    can_be_edited: bool
    is_anonymous: bool
    can_manage_chat: bool
    can_delete_messages: bool
    can_manage_voice_chats: bool
    can_restrict_members: bool
    can_promote_members: bool
    can_change_info: bool
    can_invite_users: bool
    can_post_messages: Optional[bool]
    can_edit_messages: Optional[bool]
    can_pin_messages: Optional[bool]
    custom_title: Optional[str]


class ChatMemberMember(ChatMember):
    status: str = "member"


class ChatMemberRestricted(ChatMember):
    status: str = "restricted"
    is_member: bool
    can_change_info: bool
    can_invite_users: bool
    can_pin_messages: bool
    can_send_messages: bool
    can_send_media_messages: bool
    can_send_polls: bool
    can_send_other_messages: bool
    can_add_web_page_previews: bool
    until_date: int


class ChatMemberLeft(ChatMember):
    status: str = "left"


class ChatMemberBanned(ChatMember):
    status: str = "kicked"


class ChatMemberUpdated(BaseModel):
    @root_validator(pre=True)
    def gen_message(cls, values: dict):
        if "from" in values:
            values["from_"] = values["from"]
            del values["from"]
        return values
    chat: MessageChat
    from_: MessageUser 
    date: int
    old_chat_member: ChatMember
    new_chat_member: ChatMember
    invite_link: Optional[ChatInviteLink]

class ChatMemberUpdated(BaseModel):
    @root_validator(pre=True)
    def gen_message(cls, values: dict):
        if "from" in values:
            values["from_"] = values["from"]
            del values["from"]
        return values
    chat: MessageChat
    from_: MessageUser 
    date: int
    old_chat_member: ChatMember
    new_chat_member: ChatMember
    invite_link: Optional[ChatInviteLink]

class MessageEntitiy(BaseModel):
    offset: int
    length: int
    type: str
    url: Optional[str]
    user: Optional[MessageUser]
    language: Optional[str]


class InputMediaPhoto(BaseModel):
    type: str
    media: str
    caption: Optional[str]
    prase_mode: Optional[str]
    caption_entities: Optional[List[MessageEntitiy]]


class TextMessage(BaseModel):
    content: str


class PhotoSizeItem(BaseModel):
    file_id: str
    file_unique_id: str
    file_size: int
    width: int
    height: int


class AudioMessage(BaseModel):
    file_id: str
    file_unique_id: str
    duration: int
    performer: Optional[str]
    title: Optional[str]
    file_name: Optional[str]
    mime_type: Optional[str]
    file_size: Optional[int]
    thumb: Optional[PhotoSizeItem]


class AnimationMessage(BaseModel):
    file_name: Optional[str]
    mime_type: Optional[str]
    duration: int
    width: int
    height: int
    thumb: Optional[PhotoSizeItem]
    file_id: str
    file_unique_id: str
    file_size: Optional[int]


class DocumentMessage(BaseModel):
    file_name: str
    mime_type: str
    thumb: Optional[PhotoSizeItem]
    file_id: str
    file_unique_id: str
    file_size: int


class StickerMessage(BaseModel):
    file_id: str
    file_unique_id: str
    width: int
    height: int
    is_animated: bool
    thumb: Optional[PhotoSizeItem]
    emoji: Optional[str]
    set_name: Optional[str]
    mask_position: Optional[MaskPosition]
    file_size: Optional[int]


class VideoMessage(BaseModel):
    file_id: str
    file_unique_id: str
    width: int
    height: int
    duration: int
    thumb: Optional[PhotoSizeItem]
    file_name: Optional[str]
    mime_type: Optional[str]
    file_size: Optional[int]


class VideoNoteMessage(BaseModel):
    file_id: str
    file_unique_id: str
    length: int
    duration: int
    thumb: Optional[PhotoSizeItem]
    file_size: Optional[int]


class VoiceMessage(BaseModel):
    file_id: str
    file_unique_id: str
    duration: int
    mime_type: Optional[str]
    file_size: Optional[int]


class ContactMessage(BaseModel):
    phone_number: str
    first_name: str
    last_name: Optional[str]
    user_id: Optional[int]
    vcard: Optional[str]


class DiceMessage(BaseModel):
    emoji: str
    value: int


class GameMessage(BaseModel):
    title: str
    description: str
    photo: List[PhotoSizeItem]
    text: Optional[str]
    text_entities: Optional[List[MessageEntitiy]]
    animation: Optional[AnimationMessage]


class PollOption(BaseModel):
    text: str
    voter_count: str


class PollMessage(BaseModel):
    id: str
    question: str
    options: List[PollOption]
    total_voter_count: int
    is_closed: bool
    is_anonymous: bool
    type: str
    allows_multiple_answers: bool
    correct_option_id: Optional[int]
    explanation: Optional[str]
    explanation_entities: Optional[List[MessageEntitiy]]
    open_period: Optional[int]
    close_date: Optional[int]


class VenueMessage(BaseModel):
    location: LocationMessage
    title: str
    address: str
    foursquare_id: Optional[str]
    foursquare_type: Optional[str]
    google_place_id: Optional[str]
    google_place_type: Optional[str]


class MessageAutoDeleteTimerChanged(BaseModel):
    message_auto_delete_time: int


class InvoiceMessage(BaseModel):
    title: str
    description: str
    start_parameter: str
    currency: str
    total_amount: int


class ShippingAddress(BaseModel):
    country_code: str
    state: str
    city: str
    street_line1: str
    street_line2: str
    post_code: str


class OrderInfo(BaseModel):
    name: Optional[str]
    phone_number: Optional[str]
    email: Optional[str]
    shipping_address: Optional[ShippingAddress]


class SuccessfulPaymentMessage(BaseModel):
    currency: str
    total_amount: int
    invoice_payload: str
    shipping_option_id: Optional[str]
    order_info: Optional[OrderInfo]
    telegram_payment_charge_id: str
    provider_payment_charge_id: str

class PassportFile(BaseModel):
    file_id: str
    file_unique_id: str
    file_size: int
    file_date: int

class EncryptedPassportElement(BaseModel):
    type: str
    data: Optional[str]
    phone_number: Optional[str]
    email: Optional[str]
    files: Optional[List[PassportFile]]
    front_side: Optional[PassportFile]
    reverse_side: Optional[PassportFile]
    selfie: Optional[PassportFile]
    translation: Optional[List[PassportFile]]
    hash: str

class EncryptedCredentials(BaseModel):
    data: str
    hash: str
    secert: str

class PassportData(BaseModel):
    data: List[EncryptedPassportElement]
    credentials: EncryptedCredentials

class ProximityAlertTriggered(BaseModel):
    traveler: MessageUser
    watcher: MessageUser
    distance: int

class VoiceChatStarted(BaseModel):
    pass

class VoiceChatScheduled(BaseModel):
    start_date: int

class VoiceChatEnded(BaseModel):
    duration: int

class VoiceChatParticipantsInvited(BaseModel):
    users: List[MessageUser]

class InlineKeyboardButton(BaseModel):  # 不完整
    text: str
    url: Optional[str]
    callback_data: Optional[str]

class InlineKeyboardMarkup(BaseModel):
    inline_keyboard: List[List[InlineKeyboardButton]]

class MessageBody(BaseModel):
    @root_validator(pre=True)
    def gen_message(cls, values: dict):
        if "from" in values:
            values["from_"] = values["from"]
            del values["from"]
        return values
    message_id: int
    from_: Optional[MessageUser]
    sender_chat: Optional[MessageChat]
    date: int
    chat: MessageChat
    forward_from: Optional[MessageUser]
    forward_from_chat: Optional[MessageChat]
    forward_from_message_id: Optional[int]
    forward_signature: Optional[str]
    forward_sender_name: Optional[str]
    forward_date: Optional[int]
    reply_to_message: Optional[Dict]  # type: MessageBody
    via_bot: Optional[MessageUser]
    edit_date: Optional[int]
    media_group_id: Optional[str]
    author_signature: Optional[str]
    text: Optional[str]
    entities: Optional[List[MessageEntitiy]]
    animation: Optional[AnimationMessage]
    audio: Optional[AudioMessage]
    document: Optional[DocumentMessage]
    photo: Optional[List[PhotoSizeItem]]
    sticker: Optional[StickerMessage]
    video: Optional[VideoMessage]
    video_note: Optional[VideoNoteMessage]
    voice: Optional[VoiceMessage]
    caption: Optional[str]
    caption_entities: Optional[List[MessageEntitiy]]
    contact: Optional[ContactMessage]
    dice: Optional[DiceMessage]
    game: Optional[GameMessage]
    poll: Optional[PollMessage]
    venue: Optional[VenueMessage]
    location: Optional[LocationMessage]
    new_chat_members: Optional[List[MessageUser]]
    left_chat_member: Optional[MessageUser]
    new_chat_title: Optional[str]
    new_chat_photo: Optional[List[PhotoSizeItem]]
    delete_chat_photo: Optional[bool]
    group_chat_created: Optional[bool]
    supergroup_chat_created: Optional[bool]
    channel_chat_created: Optional[bool]
    message_auto_delete_timer_changed: Optional[MessageAutoDeleteTimerChanged]
    migrate_to_chat_id: Optional[int]
    migrate_from_chat_id: Optional[int]
    pinned_message: Optional[Dict]  # type: MessageBody
    invoice: Optional[InvoiceMessage]
    successful_payment: Optional[SuccessfulPaymentMessage]
    connected_website: Optional[str]
    passport_data: Optional[PassportData]
    proximity_alert_triggered: Optional[ProximityAlertTriggered]
    voice_chat_scheduled: Optional[VoiceChatScheduled]
    voice_chat_started: Optional[VoiceChatStarted]
    voice_chat_ended: Optional[VoiceChatEnded]
    voice_chat_participants_invited: Optional[VoiceChatParticipantsInvited]
    reply_markup: Optional[InlineKeyboardMarkup]

class CallbackQuery(BaseModel):
    @root_validator(pre=True)
    def gen_message(cls, values: dict):
        values["from_"] = values["from"]
        del values["from"]
        return values
    id: str
    from_: MessageUser
    message: Optional[MessageBody]
    inline_message_id: Optional[str]
    chat_instance: Optional[str]
    data: Optional[str]
    game_short_name: Optional[str]

class InlineQuery(BaseModel):
    @root_validator(pre=True)
    def gen_message(cls, values: dict):
        if "from" in values:
            values["from_"] = values["from"]
            del values["from"]
        return values
    id: str
    from_: MessageUser
    query: str
    offset: str
    chat_type: Optional[MessageType]
    location: Optional[LocationMessage]


class SendText(BaseModel):
    chat_id: Optional[Union[int, str]]
    text: str
    parse_mode: Optional[str]
    entities: Optional[List[MessageEntitiy]]
    disable_web_page_preview: Optional[bool]
    disable_notification: Optional[bool]
    reply_to_message_id: Optional[int]
    allow_sending_without_reply: Optional[bool]
    reply_markup: Optional[InlineKeyboardMarkup]


class SendPhoto(BaseModel):
    chat_id: Optional[Union[int, str]]
    photo: Optional[str]
    caption: Optional[str]
    parse_mode: Optional[str]
    caption_entities: Optional[List[MessageEntitiy]]
    disable_notification: Optional[bool]
    reply_to_message_id: Optional[int]
    allow_sending_without_reply: Optional[bool]
    reply_markup: Optional[InlineKeyboardMarkup]


class SendAudio(BaseModel):
    chat_id: Optional[Union[int, str]]
    audio: Optional[str]
    caption: Optional[str]
    parse_mode: Optional[str]
    caption_entities: Optional[List[MessageEntitiy]]
    duration: Optional[int]
    performer: Optional[str]
    title: Optional[str]
    thumb: Optional[str]
    disable_notification: Optional[bool]
    reply_to_message_id: Optional[int]
    allow_sending_without_reply: Optional[bool]
    reply_markup: Optional[InlineKeyboardMarkup]


class EditMessageText(BaseModel):
    chat_id: Optional[Union[int, str]]
    message_id: Optional[int]
    inline_message_id: Optional[str]
    text: str
    parse_mode: Optional[str]
    entities: Optional[List[MessageEntitiy]]
    disable_web_page_preview: Optional[bool]
    reply_markup: Optional[InlineKeyboardMarkup]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['nonebot', 'nonebot.adapters.telegram']

package_data = \
{'': ['*']}

install_requires = \
['httpx>=0.17.0,<0.18.0', 'nonebot2>=2.0.0a13.post1,<3.0.0']

setup_kwargs = {
    'name': 'nonebot-adapter-antelegram',
    'version': '0.1.0.dev3',
    'description': 'Another unofficial Telegram adapter for nonebot2',
    'long_description': '# nonebot-adapter-telegram\n（施工中）自己用的非官方nonebot2 telegram adapter，代码全靠糊  \n开发中代码没有经过清理和优化，不能与官方版本共存  \n当前仅支持有限类型的消息解析和发送（接受私聊/群聊文字/图片，发送私聊/群聊文字/图片/语音，入群事件）  \n需要公网ip或者frp  \n演示bot[@aya_od_bot](https://t.me/aya_od_bot)  \n## 使用方法\n如果要试毒的话  \n真的要的话  \n```shell\npip install nonebot-adapter-antelegram\n```\n## 上路\n一、 \n新建项目文件夹\n二、  \n在nonebot2的配置文件中配置以下选项  \n```shell\nhost=127.0.0.1 # 配置 NoneBot 监听的 IP / 主机名  \nport=xxxxx     # 配置 NoneBot 监听的端口  \nwebhook_host=your_domain # 配置telegram webhook域名，由于telegram要求webhook地址必须为https，我们需要在之后配置反向代理  \nbot_token=your_bot_token  #telegram bot token\n```\n三、\n将域名解析到本机，用你喜欢的方式配置反代将webhook域名的流量转发到nonebot2的监听端口  \n四、\n开始写机器人（摸鱼）\n\n## 最简单的例子\nbot.py\n```python\nimport nonebot\nfrom nonebot.adapters.telegram import Bot\n\nnonebot.init()\ndriver = nonebot.get_driver()\ndriver.register_adapter("your_bot_token", Bot) #your_bot_token替换为bot的token\nnonebot.load_plugin("plugins.echo")\n\nif __name__ == "__main__":\n    nonebot.run()   \n```\nplugins/echo.py\n```python\nfrom nonebot.plugin import on, on_command\nfrom nonebot.adapters.telegram import Bot, MessageEvent, Message, MessageSegment\nfrom nonebot.rule import to_me\n\necho = on_command("echo",to_me())\n\n@echo.handle()\nasync def echo_escape(bot: Bot, event: MessageEvent):\n    await bot.send(message=event.get_message(), event=event)\n\n#await bot.send(message="114514", event=event) #发送文字\n#await bot.send(message=MessageSegment.photo(pic_url)), event=event) #发送图片 支持file:///，base64://，file_id，url(由Telegram服务器下载)\n```\n运行机器人，向bot私聊发送/echo 123，bot会将消息原样重新发送\n\n\n',
    'author': 'ColdThunder11',
    'author_email': 'lslyj27761@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/ColdThunder11/nonebot-adapter-telegram',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7.3,<4.0.0',
}


setup(**setup_kwargs)
